import { parse, GraphQLSchema, ParseOptions, ValidationRule, FragmentDefinitionNode, DocumentNode } from 'graphql';
import type { IPosition } from 'graphql-language-service-types';
import { defaultSchemaLoader, SchemaConfig } from './schemaLoader';
export declare type GraphQLLanguageConfig = {
    parser?: typeof parse;
    jsonParser?: typeof JSON.parse;
    schemaLoader?: typeof defaultSchemaLoader;
    parseOptions?: ParseOptions;
    schemas?: SchemaConfig[];
    exteralFragmentDefinitions?: FragmentDefinitionNode[] | string;
};
declare type SchemaCacheItem = Omit<SchemaConfig, 'schema'> & {
    schema: GraphQLSchema;
};
export declare class LanguageService {
    private _parser;
    private _schemas;
    private _schemaCache;
    private _schemaLoader;
    private _parseOptions;
    private _exteralFragmentDefinitionNodes;
    private _exteralFragmentDefinitionsString;
    constructor({ parser, schemas, parseOptions, exteralFragmentDefinitions, }: GraphQLLanguageConfig);
    private _cacheSchemas;
    private _cacheSchema;
    getSchemaForFile(uri: string): SchemaCacheItem | undefined;
    getExternalFragmentDefinitions(): FragmentDefinitionNode[];
    updateSchemas(schemas: SchemaConfig[]): Promise<void>;
    updateSchema(schema: SchemaConfig): void;
    addSchema(schema: SchemaConfig): void;
    parse(text: string, options?: ParseOptions): DocumentNode;
    getCompletion: (uri: string, documentText: string, position: IPosition) => import("graphql-language-service-types").CompletionItem[];
    getDiagnostics: (uri: string, documentText: string, customRules?: ValidationRule[] | undefined) => import("vscode-languageserver-types").Diagnostic[];
    getHover: (uri: string, documentText: string, position: IPosition) => string | import("vscode-languageserver-types").MarkupContent | {
        language: string;
        value: string;
    } | import("vscode-languageserver-types").MarkedString[] | undefined;
    getVariablesJSONSchema: (uri: string, documentText: string) => import("json-schema").JSONSchema6 | null;
}
export {};
//# sourceMappingURL=LanguageService.d.ts.map